import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"
    
    def test_list_other_items(self):

        fc = self.fc

        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'

        list_dashboards = fc.list_dashboards(workspace_id)
        dashboard_names = [dashboard.display_name for dashboard in list_dashboards]
        self.assertGreater(len(list_dashboards), 0)
        self.assertIn("dashboardpbi", dashboard_names)

        # list_datamarts = fc.list_datamarts(workspace_id)
        # datamart_names = [datamart.display_name for datamart in list_datamarts]
        # self.assertGreater(len(list_datamarts), 0)
        # self.assertIn("datamart1", datamart_names)

        list_sql_endpoints = fc.list_sql_endpoints(workspace_id)
        sqlendpoint_names = [sqlendpoint.display_name for sqlendpoint in list_sql_endpoints]
        self.assertGreater(len(list_sql_endpoints), 0)
        self.assertIn("lakelhousewlabels", sqlendpoint_names)

        # list_mirrored_warehouses = fc.list_mirrored_warehouses(self.workspace_id)
        # self.assertGreater(len(list_mirrored_warehouses), 0)

        # list_paginated_reports = fc.list_paginated_reports(self.workspace_id)
        # self.assertGreater(len(list_paginated_reports), 0)


import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_apache_airflow_job(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "4e685286-d909-4ccb-911f-590ee3c3df14"

        apache_airflow_job = fcc.list_apache_airflow_jobs(workspace_id=workspace_id)
        for apache_airflow_job in apache_airflow_job:
            if apache_airflow_job.id != item_id:
                resp = fcc.delete_apache_airflow_job(workspace_id=workspace_id, apache_airflow_job_id=apache_airflow_job.id)
                self.assertEqual(resp, 200)

        apache_airflow_job_definition = fcc.get_apache_airflow_job_definition(workspace_id=workspace_id, apache_airflow_job_id=item_id)
        self.assertIn("definition", apache_airflow_job_definition)
        definition = apache_airflow_job_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"copyjob{date_str}"

        apache_airflow_job_new = fcc.create_apache_airflow_job(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(apache_airflow_job_new.display_name, date_str)

        apache_airflow_job_get = fcc.get_apache_airflow_job(workspace_id=workspace_id, apache_airflow_job_id=apache_airflow_job_new.id)
        self.assertEqual(apache_airflow_job_get.display_name, date_str)

        apache_airflow_job = fcc.list_apache_airflow_jobs(workspace_id=workspace_id)
        self.assertEqual(len(apache_airflow_job), 2)

        date_str_updated = date_str + "_updated"
        apache_airflow_job_updated = fcc.update_apache_airflow_job(workspace_id=workspace_id, apache_airflow_job_id=apache_airflow_job_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(apache_airflow_job_updated.display_name, date_str_updated)

        apache_airflow_job_updated = fcc.update_apache_airflow_job_definition(workspace_id=workspace_id, apache_airflow_job_id=apache_airflow_job_new.id, definition=definition)
        self.assertEqual(apache_airflow_job_updated.status_code, 200)

        for apache_airflow_job in apache_airflow_job:
            if apache_airflow_job.id != item_id:
                resp = fcc.delete_apache_airflow_job(workspace_id=workspace_id, apache_airflow_job_id=apache_airflow_job.id)
                self.assertEqual(resp, 200)










import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientAdmin

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fca = FabricClientAdmin()
                  
    def test_admin_api(self):
        fca = self.fca

        sdk_tag = [tag for tag in fca.list_tags() if tag["displayName"] == "sdk_tag_temp"]
        if len(sdk_tag) > 0:
            sdk_tag = sdk_tag[0]
            resp = fca.delete_tag(tag_id=sdk_tag["id"])
            self.assertEqual(resp, 200)
      
        new_tags = [{"displayName": "sdk_tag_temp"}]
        resp = fca.bulk_create_tags(create_tags_request=new_tags)
        self.assertEqual(len(resp["tags"]), 1)
        resp = resp["tags"][0]
        self.assertEqual(resp["displayName"], "sdk_tag_temp")

        sdk_tag = [tag for tag in fca.list_tags() if tag["displayName"] == "sdk_tag_temp"]
        self.assertEqual(len(sdk_tag), 1)
        sdk_tag = sdk_tag[0]

        self.assertIsNotNone(sdk_tag["id"])

        resp = fca.update_tag(tag_id=sdk_tag["id"], display_name="sdk_tag_updated")
        self.assertIsNotNone(resp["id"])
        self.assertEqual(resp["displayName"], "sdk_tag_updated")


        resp = fca.delete_tag(tag_id=resp["id"])
        self.assertEqual(resp, 200)

        sdk_tag = [tag for tag in fca.list_tags() if tag["displayName"] == "sdk_tag_temp"]
        self.assertEqual(len(sdk_tag), 0)






import unittest
from msfabricpysdkcore.coreapi import FabricClientCore
from dotenv import load_dotenv
from datetime import datetime

load_dotenv()


class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()


    def test_spark_workspace_custom_pools(self):
        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        pool_name = "pool" + datetime.now().strftime("%Y%m%d%H%M%S")
        # List 

        pools = fc.list_workspace_custom_pools(workspace_id=workspace_id)
        self.assertGreater(len(pools), 0)

        pools = fc.list_workspace_custom_pools(workspace_id=workspace_id)

        self.assertIn("pool1", [p.name for p in pools])
        pool1 = [p for p in pools if p.name == "pool1"][0]

        # Get

        pool1_clone = fc.get_workspace_custom_pool(workspace_id=workspace_id, pool_id=pool1.id)
        self.assertEqual(pool1_clone.id, pool1.id)
        # Create

        pool2 = fc.create_workspace_custom_pool(workspace_id=workspace_id, 
                                        name=pool_name, 
                                        node_family="MemoryOptimized",
                                        node_size="Small", 
                                        auto_scale = {"enabled": True, "minNodeCount": 1, "maxNodeCount": 2},
                                        dynamic_executor_allocation = {"enabled": True, "minExecutors": 1, "maxExecutors": 1})

        self.assertEqual(pool2.name, pool_name)
        self.assertEqual(pool2.node_family, "MemoryOptimized")

        # Update

        pool2 = fc.update_workspace_custom_pool(workspace_id=workspace_id, pool_id=pool2.id,
                                        auto_scale = {"enabled": True, "minNodeCount": 1, "maxNodeCount": 7},
                                        return_item=True)

        self.assertEqual(pool2.auto_scale["maxNodeCount"], 7)
        pool2_clone = fc.get_workspace_custom_pool(workspace_id=workspace_id, pool_id=pool2.id)
        self.assertEqual(pool2_clone.auto_scale["maxNodeCount"], 7)

        # Delete
        status_code = fc.delete_workspace_custom_pool(workspace_id=workspace_id, pool_id=pool2.id)
        self.assertEqual(status_code, 200)

        pools = fc.list_workspace_custom_pools(workspace_id=workspace_id)
        self.assertNotIn(pool_name, [p.name for p in pools])

    def test_workspace_settings(self):
        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'

        # Get

        settings = fc.get_spark_settings(workspace_id)
        self.assertIn("automaticLog", settings)
        
        
        orig_setting = settings["automaticLog"]["enabled"]
        settings["automaticLog"]["enabled"] = not settings["automaticLog"]["enabled"]

        # Update
        settings = fc.update_spark_settings(workspace_id, automatic_log=settings["automaticLog"])
        new_setting = settings["automaticLog"]["enabled"]
        self.assertNotEqual(orig_setting, new_setting)
        self.assertTrue(orig_setting or new_setting)
        self.assertFalse(orig_setting and new_setting)

        settings = fc.get_spark_settings(workspace_id)
        checked_setting = settings["automaticLog"]["enabled"]
        self.assertEqual(checked_setting, new_setting)


if __name__ == "__main__":
    unittest.main()





# import unittest
# from dotenv import load_dotenv
# from msfabricpysdkcore import FabricClientCore
# from datetime import datetime
# from time import sleep
# load_dotenv()

# class TestFabricClientCore(unittest.TestCase):

#     def __init__(self, *args, **kwargs):
#         super(TestFabricClientCore, self).__init__(*args, **kwargs)
                  
#     def test_eventstream_topology(self):

        # fcc = FabricClientCore()

        # workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"

        # item_id = "94f4b54b-980b-43f9-8b67-ded8028cf1b9"
        # custom_destination_id = "acd90d61-2792-4494-9f17-c822f2fb984d"
        # custom_source_id = "9f382928-7d42-43f9-b02b-1b1352ad3ecd"
        # source_id = "e58db369-e473-40f4-bedd-022b60540b17"
        # destination_id = "2446e6cf-98c9-45cb-a102-78d2ca3eb257"


        # topology = fcc.get_eventstream_topology(workspace_id, item_id)
        # self.assertIsNotNone(topology)
        # self.assertIn("sources", topology)
        # self.assertIn("destinations", topology)

        # destination = fcc.get_eventstream_destination(workspace_id, item_id, destination_id)
        # self.assertIsNotNone(destination)
        # self.assertEqual(destination["id"], destination_id)

        # destination_conn = fcc.get_eventstream_destination_connection(workspace_id, item_id, custom_destination_id)
        # self.assertIsNotNone(destination_conn)
        # self.assertIn("fullyQualifiedNamespace", destination_conn)

        # source = fcc.get_eventstream_source(workspace_id, item_id, source_id)
        # self.assertIsNotNone(source)
        # self.assertEqual(source["id"], source_id)

        # source_conn = fcc.get_eventstream_source_connection(workspace_id, item_id, custom_source_id)
        # self.assertIsNotNone(source_conn)
        # self.assertIn("fullyQualifiedNamespace", source_conn)

        # resp = fcc.pause_eventstream(workspace_id, item_id)
        # self.assertEqual(resp, 200)

        # def resume():
        #     resp = fcc.resume_eventstream(workspace_id, item_id, start_type="Now")
        #     self.assertEqual(resp, 200)

        # for _ in range(12):
        #     try:
        #         resume()
        #         break
        #     except Exception as e:
        #         sleep(5)
        
        # resp = fcc.pause_eventstream_source(workspace_id, item_id, source_id)
        # self.assertEqual(resp, 200)

        # resp = fcc.pause_eventstream_destination(workspace_id, item_id, destination_id)
        # self.assertEqual(resp, 200)

        # resp = fcc.resume_eventstream_source(workspace_id, item_id, source_id, start_type="Now")
        # self.assertEqual(resp, 200)

        # def resume():
        #     resp = fcc.resume_eventstream_destination(workspace_id, item_id, destination_id, start_type="Now")
        #     self.assertEqual(resp, 200)
        
        # for _ in range(12):
        #     try:
        #         resume()
        #         break
        #     except Exception as e:
        #         sleep(5)





import unittest
from msfabricpysdkcore.coreapi import FabricClientCore
from datetime import datetime
from dotenv import load_dotenv
import time

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
        
    def test_deployment_pipeline2(self):
        fcc = self.fc
        workspace_id = "72d9d955-bd1e-42c7-9746-208f7cbc8956"

        user_id = "e0505016-ef55-4ca7-b106-e085cc201823"
        capacity_id = "9e7e757d-d567-4fb3-bc4f-d230aabf2a00"

        prod_workspace = fcc.create_workspace("sdkswedenproddeploy")
        prod_workspace.assign_to_capacity(capacity_id)

        stages =  [
            {
            "displayName": "Development",
            "description": "Development stage description",
            "isPublic": False
            },
            {
            "displayName": "Production",
            "description": "Production stage description",
            "isPublic":True
            }
        ]

        pipes = fcc.list_deployment_pipelines(with_details=False)
        for pipe in pipes:
            if "sdk" in pipe["displayName"]:
                fcc.delete_deployment_pipeline(deployment_pipeline_id=pipe["id"])
        
        pipe =fcc.create_deployment_pipeline(display_name="sdktestpipeline",
                              description="Test Deployment Pipeline Description",
                              stages=stages)
        
        self.assertIsNotNone(pipe.id)
        pipe_id = pipe.id

        for stage in pipe.stages:
            if stage["displayName"] == "Development":
                dev_stage = stage
            else:
                prod_stage = stage
        
        stage = fcc.get_deployment_pipeline_stage(deployment_pipeline_id=pipe_id,
                                                  stage_id=dev_stage["id"])
        self.assertIsNotNone(stage.id)
        resp = fcc.assign_workspace_to_stage(deployment_pipeline_id=pipe_id,
                              stage_id=dev_stage["id"],
                              workspace_id=workspace_id)
        self.assertEqual(resp, 200)

        resp = fcc.assign_workspace_to_stage(deployment_pipeline_id=pipe_id,
                              stage_id=prod_stage["id"],
                              workspace_id=prod_workspace.id)
        self.assertEqual(resp, 200)
        principal = {
            "id": user_id,
            "type": "User"
        }

        resp = fcc.add_deployment_pipeline_role_assignment(deployment_pipeline_id=pipe_id,principal=principal, role="Admin")
        self.assertEqual(resp, 200)

        roles = fcc.list_deployment_pipeline_role_assignments(deployment_pipeline_id=pipe_id)
        self.assertTrue(len(roles) == 2)

        resp = fcc.delete_deployment_pipeline_role_assignment(deployment_pipeline_id=pipe_id, principal_id=user_id)
        self.assertEqual(resp, 200)

        roles = fcc.list_deployment_pipeline_role_assignments(deployment_pipeline_id=pipe_id)
        self.assertTrue(len(roles) == 1)

        pipes = fcc.list_deployment_pipelines(with_details=False)
        sdk_pipes = [pipe for pipe in pipes  if "sdk" in pipe["displayName"]]
        self.assertTrue(len(sdk_pipes) > 0)

        resp = fcc.deploy_stage_content(deployment_pipeline_id=pipe_id,
                        source_stage_id=dev_stage["id"],
                        target_stage_id=prod_stage["id"], wait_for_completion=False)
        self.assertEqual(resp.status_code, 202)

        ops = fcc.list_deployment_pipeline_operations(deployment_pipeline_id=pipe_id)
        self.assertTrue(len(ops) > 0)

        ops = fcc.get_deployment_pipeline_operation(deployment_pipeline_id=pipe_id, operation_id=ops[0]["id"])
        self.assertIsNotNone(ops["id"])

        stages = fcc.list_deployment_pipeline_stages(deployment_pipeline_id=pipe_id)
        self.assertTrue(len(stages) == 2)

        items = fcc.list_deployment_pipeline_stage_items(deployment_pipeline_id=pipe_id, stage_id=dev_stage["id"])
        self.assertTrue(len(items) == 1)

        updated_pipe = fcc.update_deployment_pipeline(deployment_pipeline_id=pipe.id, display_name="sdknewname", description="newdescription")
        self.assertIsNotNone(updated_pipe.id)

        pipe = fcc.get_deployment_pipeline(pipe_id)
        self.assertIsNotNone(pipe.id)
        self.assertTrue(pipe.display_name == "sdknewname")

        updated_stage = fcc.update_deployment_pipeline_stage(deployment_pipeline_id=pipe_id, stage_id=prod_stage["id"],
                                                     display_name="newname", description="newdescription")
        self.assertIsNotNone(updated_stage["id"])

        stage = fcc.get_deployment_pipeline_stage(deployment_pipeline_id=pipe_id, stage_id=prod_stage["id"])
        self.assertIsNotNone(stage.id)
        self.assertTrue(stage.display_name == "newname")

        for _ in range(10):
            ops = fcc.get_deployment_pipeline_operation(deployment_pipeline_id=pipe_id, operation_id=ops["id"])
            if ops["status"] != "Running":
                break
            else:
                time.sleep(5)

        resp = fcc.unassign_workspace_from_stage(deployment_pipeline_id=pipe_id,stage_id=prod_stage["id"])
        self.assertEqual(resp, 200)

        prod_workspace.delete()

        resp = fcc.delete_deployment_pipeline(deployment_pipeline_id=pipe_id)
        self.assertEqual(resp, 200)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"



    def test_eventhouses(self):
            
        fcc = self.fc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "5d544ac1-c58d-4d3a-a032-f57dc4b5c2a7"

        eventhouses = fcc.list_eventhouses(workspace_id=workspace_id)
        for eventhouse in eventhouses:
            if eventhouse.id != item_id:
                resp = fcc.delete_eventhouse(workspace_id=workspace_id, eventhouse_id=eventhouse.id)
                self.assertEqual(resp, 200)

        eventhouse_definition = fcc.get_eventhouse_definition(workspace_id=workspace_id, eventhouse_id=item_id)
        self.assertIn("definition", eventhouse_definition)
        definition = eventhouse_definition["definition"]

        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"eventhouse{date_str}"

        eventhouse_new = fcc.create_eventhouse(workspace_id=workspace_id, display_name=date_str, definition=definition)

        self.assertEqual(eventhouse_new.display_name, date_str)

        eventhouse_get = fcc.get_eventhouse(workspace_id=workspace_id, eventhouse_id=eventhouse_new.id)
        self.assertEqual(eventhouse_get.display_name, date_str)

        eventhouses = fcc.list_eventhouses(workspace_id=workspace_id)
        self.assertEqual(len(eventhouses), 2)

        date_str_updated = date_str + "_updated"
        eventhouse_updated = fcc.update_eventhouse(workspace_id=workspace_id, eventhouse_id=eventhouse_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(eventhouse_updated.display_name, date_str_updated)

        eventhouse_updated = fcc.update_eventhouse_definition(workspace_id=workspace_id, eventhouse_id=eventhouse_new.id, definition=definition)
        self.assertIn(eventhouse_updated.status_code, [200, 202])

        for eventhouse in eventhouses:
            if eventhouse.id != item_id:
                resp = fcc.delete_eventhouse(workspace_id=workspace_id, eventhouse_id=eventhouse.id)
                self.assertEqual(resp, 200)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fc = FabricClientCore()

    def test_environments_crudl(self):
        fcc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        item_id = '35a08bcb-ff8c-40f7-93ea-b86dc1affce5'

        environments = fcc.list_environments(workspace_id=workspace_id)
        for environment in environments:
            if environment.id != item_id:
                resp = fcc.delete_environment(workspace_id=workspace_id, environment_id=environment.id)
                self.assertEqual(resp, 200)


        date_str = datetime.now().strftime("%Y-%m-%d %H:%M:%S")
        date_str = date_str.replace(" ", "T").replace(":", "").replace("-", "")
        date_str = f"environment{date_str}"

        environment_new = fcc.create_environment(workspace_id=workspace_id, display_name=date_str)

        self.assertEqual(environment_new.display_name, date_str)

        environment_get = fcc.get_environment(workspace_id=workspace_id, environment_id=environment_new.id)
        self.assertEqual(environment_get.display_name, date_str)

        environments = fcc.list_environments(workspace_id=workspace_id)
        self.assertEqual(len(environments), 2)

        date_str_updated = date_str + "_updated"
        environment_updated = fcc.update_environment(workspace_id=workspace_id, environment_id=environment_new.id, display_name=date_str_updated, return_item=True)
        self.assertEqual(environment_updated.display_name, date_str_updated)

        for environment in environments:
            if environment.id != item_id:
                resp = fcc.delete_environment(workspace_id=workspace_id, environment_id=environment.id)
                self.assertEqual(resp, 200)

    def test_environment_details(self):
        fc = FabricClientCore()
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        environment_id = '35a08bcb-ff8c-40f7-93ea-b86dc1affce5'

        published_settings = fc.get_published_settings(workspace_id=workspace_id, environment_id=environment_id)
        self.assertIsNotNone(published_settings)
        self.assertIn("instancePool", published_settings)
        self.assertIn("dynamicExecutorAllocation", published_settings)
        staging_settings = fc.get_staging_settings(workspace_id=workspace_id, environment_id=environment_id)
        self.assertIsNotNone(staging_settings)
        self.assertIn("instancePool", staging_settings)
        self.assertIn("dynamicExecutorAllocation", staging_settings)
        if staging_settings["driverCores"] == 8:
            driver_cores = 4
        else:
            driver_cores = 8
        updated_settings = fc.update_staging_settings(workspace_id=workspace_id, environment_id=environment_id, driver_cores=driver_cores)
        self.assertIn("instancePool", updated_settings)
        self.assertIn("dynamicExecutorAllocation", updated_settings)
        self.assertEqual(updated_settings["driverCores"], driver_cores)
        updated_settings = fc.get_staging_settings(workspace_id=workspace_id, environment_id=environment_id)
        self.assertIn("instancePool", updated_settings)
        self.assertIn("dynamicExecutorAllocation", updated_settings)
        self.assertEqual(updated_settings["driverCores"], driver_cores)


    def test_environment_spark_libraries(self):
        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        environment_id = '35a08bcb-ff8c-40f7-93ea-b86dc1affce5'

        resp = fc.get_published_libraries(workspace_id, environment_id)
        self.assertIn('customLibraries', resp)
        self.assertIn('wheelFiles', resp['customLibraries'])
        self.assertIn('msfabricpysdkcore-0.2.6-py3-none-any.whl', resp['customLibraries']['wheelFiles'])

        resp = fc.upload_staging_library(workspace_id, environment_id, 'dummy.whl')
        self.assertEqual(resp.status_code, 200)
        
        resp = fc.get_staging_libraries(workspace_id, environment_id)

        self.assertIn('customLibraries', resp)
        self.assertIn('wheelFiles', resp['customLibraries'])
        self.assertIn('dummy.whl', resp['customLibraries']['wheelFiles'])

        
        resp = fc.publish_environment(workspace_id, environment_id)
        self.assertIn('publishDetails', resp)
        self.assertIn('state', resp['publishDetails'])
        self.assertEqual(resp['publishDetails']['state'].lower(), 'running')

        
        resp = fc.cancel_publish(workspace_id, environment_id)
        self.assertIn('publishDetails', resp)
        self.assertIn('state', resp['publishDetails'])
        self.assertEqual(resp['publishDetails']['state'].lower(), 'cancelled')

        resp = fc.delete_staging_library(workspace_id, environment_id, 'dummy.whl')
        self.assertEqual(resp.status_code, 200)

        resp = fc.get_staging_libraries(workspace_id, environment_id)

        self.assertIn('customLibraries', resp)
        self.assertIn('wheelFiles', resp['customLibraries'])
        self.assertNotIn('dummy.whl', resp['customLibraries']['wheelFiles'])


        






import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")

    
    def test_ml_experiments(self):
            
        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        mlexperiment_name = "mlexp" + datetime.now().strftime("%Y%m%d%H%M%S")
        mlexperiment_name2 = "mlexp2" + datetime.now().strftime("%Y%m%d%H%M%S")

        ml_experiment = fc.create_ml_experiment(workspace_id, display_name=mlexperiment_name)
        self.assertEqual(ml_experiment.display_name, mlexperiment_name)
        
        ml_experiments = fc.list_ml_experiments(workspace_id)
        ml_experiment_names = [mle.display_name for mle in ml_experiments]
        self.assertGreater(len(ml_experiments), 0)
        self.assertIn(mlexperiment_name, ml_experiment_names)

        mle = fc.get_ml_experiment(workspace_id, ml_experiment_name=mlexperiment_name)
        self.assertIsNotNone(mle.id)
        self.assertEqual(mle.display_name, mlexperiment_name)

        mle2 = fc.update_ml_experiment(workspace_id, mle.id, display_name=mlexperiment_name2, return_item=True)

        mle = fc.get_ml_experiment(workspace_id, ml_experiment_id=mle.id)
        self.assertEqual(mle.display_name, mlexperiment_name2)
        self.assertEqual(mle.id, mle2.id)

        status_code = fc.delete_ml_experiment(workspace_id, mle.id)
        self.assertEqual(status_code, 200)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"


    def test_warehouses(self):

        fc = self.fc
        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        warehouse1 = f"wh{datetime_str}"
        warehouse = fc.create_warehouse(workspace_id, display_name=warehouse1)
        self.assertIsNotNone(warehouse.id)

        warehouses = fc.list_warehouses(workspace_id)
        warehouse_names = [wh.display_name for wh in warehouses]
        self.assertGreater(len(warehouses), 0)
        self.assertIn(warehouse1, warehouse_names)

        warehouse = fc.get_warehouse(workspace_id, warehouse_name=warehouse1)
        self.assertIsNotNone(warehouse.id)
        self.assertEqual(warehouse.display_name, warehouse1)

        warehouse2 = fc.update_warehouse(workspace_id, warehouse.id, display_name=f"{warehouse1}2", return_item=True)
        warehouse = fc.get_warehouse(workspace_id, warehouse_id=warehouse.id)
        self.assertEqual(warehouse.display_name, f"{warehouse1}2")
        self.assertEqual(warehouse.id, warehouse2.id)

        status_code = fc.delete_warehouse(workspace_id, warehouse.id)
        self.assertEqual(status_code, 200)


if __name__ == "__main__":
    unittest.main()


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
    
    def test_mirrored_database(self):

        fc = self.fc
        workspace_id = '46425c13-5736-4285-972c-6d034020f3ff'
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")

        mirrored_db_name = "mirrored_db" + datetime_str

        # mirrored_db_w_content = fc.get_mirrored_database(workspace_id, mirrored_database_name="dfsdemo")

        # status = fc.get_mirroring_status(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)
        # self.assertIsNotNone(status)
        # self.assertIn("status", status)

        # status = status["status"]

        # if status == 'Running':
        #     fc.stop_mirroring(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)
        #     sleep(60)
        #     fc.start_mirroring(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)
        # else:
        #     fc.start_mirroring(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)
        #     sleep(60)
        #     fc.stop_mirroring(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)

        # table_status = fc.get_tables_mirroring_status(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)

        # self.assertIsNotNone(table_status)
        # self.assertIn("data", table_status)
        # for _ in range(5):
        #     if len(table_status["data"]) > 0:
        #         break
        #     sleep(60)
        #     table_status = fc.get_tables_mirroring_status(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)
        # self.assertIn("sourceTableName", table_status["data"][0])

        # fc.stop_mirroring(workspace_id=workspace_id, mirrored_database_id=mirrored_db_w_content.id)

        # definition = fc.get_mirrored_database_definition(workspace_id, mirrored_db_w_content.id)
        # self.assertIsNotNone(definition)
        # self.assertIn("definition", definition)
        # self.assertIn("parts", definition["definition"])

        # mirrored_db = fc.create_mirrored_database(workspace_id, display_name=mirrored_db_name)
        
        # mirrored_db_check = fc.get_mirrored_database(workspace_id, mirrored_database_id=mirrored_db.id)
        # self.assertEqual(mirrored_db_check.display_name, mirrored_db_name)
        # self.assertIsNotNone(mirrored_db_check.id)
        # self.assertEqual(mirrored_db_check.id, mirrored_db_check.id)

        # mirrored_dbs = fc.list_mirrored_databases(workspace_id)
        # mirrored_db_names = [md.display_name for md in mirrored_dbs]
        # self.assertGreater(len(mirrored_dbs), 0)
        # self.assertIn(mirrored_db_name, mirrored_db_names)

        # sleep(60)

        # mirrored_db_2 = fc.update_mirrored_database(workspace_id, mirrored_db_check.id,
        #                                             display_name=f"u{mirrored_db_name}", return_item=True)
        # mirrored_db_2 = fc.get_mirrored_database(workspace_id, mirrored_database_id=mirrored_db_2.id)

        # self.assertEqual(mirrored_db_2.display_name, f"u{mirrored_db_name}")

        # status_code = fc.delete_mirrored_database(workspace_id, mirrored_db_2.id)
        # self.assertEqual(status_code, 200)


import unittest
from dotenv import load_dotenv
from msfabricpysdkcore import FabricClientCore
from datetime import datetime
load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fcc = FabricClientCore()
                  
    def test_sql_endpoint(self):
        fcc = self.fcc

        workspace_id = "05bc5baa-ef02-4a31-ab20-158a478151d3"
        item_id = "d21012a1-f306-4cf1-a21b-f8ae55c17642"

        response = fcc.refresh_sql_endpoint_metadata(workspace_id=workspace_id, sql_endpoint_id=item_id, wait_for_completion=False)
        self.assertIn(response.status_code, [200, 202])











import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"


    def test_reports(self):
                
        fc = self.fc
        workspace_id = '63aa9e13-4912-4abe-9156-8a56e565b7a3'

        report_name = "report1234"

        report_w_content = fc.get_report(workspace_id, report_name="HelloWorldReport")

        definition = fc.get_report_definition(workspace_id, report_w_content.id)
        
        self.assertIsNotNone(definition)
        self.assertIn("definition", definition)
        definition = definition["definition"]

        report = fc.create_report(workspace_id, display_name=report_name, definition=definition)
        fc.update_report_definition(workspace_id, report.id, definition=definition)
        report = fc.get_report(workspace_id, report_id=report.id)
        self.assertEqual(report.display_name, report_name)
        self.assertIsNotNone(report.definition)
        
        reports = fc.list_reports(workspace_id)
        report_names = [r.display_name for r in reports]
        self.assertGreater(len(reports), 0)
        self.assertIn(report_name, report_names)

        r = fc.get_report(workspace_id, report_name=report_name)
        self.assertIsNotNone(r.id)
        self.assertEqual(r.display_name, report_name)

        r2 = fc.update_report(workspace_id, r.id, display_name=f"{report_name}2", return_item=True)
        self.assertEqual(r2.display_name, f"{report_name}2")
        self.assertEqual(r2.id, r.id)

        status_code = fc.delete_report(workspace_id, r.id)
        self.assertEqual(status_code, 200)


import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
        self.workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'


        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        self.item_name = "testitem" + datetime_str
        self.item_type = "Notebook"
    
    def test_item_end_to_end(self):

        item = self.fc.create_item(display_name=self.item_name, type=self.item_type, workspace_id=self.workspace_id) 
        self.assertEqual(item.display_name, self.item_name)
        self.assertEqual(item.type, self.item_type)
        self.assertEqual(item.workspace_id, self.workspace_id)
        self.assertEqual(item.description, "")

        item = self.fc.get_item(workspace_id=self.workspace_id, item_id=item.id)
        item_ = self.fc.get_item(workspace_id=self.workspace_id,
                                  item_name=self.item_name, item_type=self.item_type)
        self.assertEqual(item.id, item_.id)
        self.assertEqual(item.display_name, self.item_name)
        self.assertEqual(item.type, self.item_type)
        self.assertEqual(item.workspace_id, self.workspace_id)
        self.assertEqual(item.description, "")

        item_list = self.fc.list_items(workspace_id=self.workspace_id)
        self.assertTrue(len(item_list) > 0)

        item_ids = [item_.id for item_ in item_list]
        self.assertIn(item.id, item_ids)

        self.fc.update_item(workspace_id=self.workspace_id, item_id=item.id, display_name=f"u{self.item_name}", return_item=True)
        item = self.fc.get_item(workspace_id=self.workspace_id, item_id=item.id)
        self.assertEqual(item.display_name, f"u{self.item_name}")

        status_code = self.fc.delete_item(workspace_id=self.workspace_id, item_id=item.id)

        self.assertAlmostEqual(status_code, 200)

    def test_item_definition(self):

        sjd = self.fc.get_item(workspace_id=self.workspace_id, item_name="helloworld", item_type="SparkJobDefinition")
        self.assertIsNotNone(sjd.definition)
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        blubb2 = "blubb2" + datetime_str
        blubb3 = "blubb3" + datetime_str
        blubb2 = self.fc.create_item(display_name=blubb2, type="SparkJobDefinition", workspace_id=self.workspace_id,
                                   definition=sjd.definition)

        blubb3 =  self.fc.create_item(display_name=blubb3, type="SparkJobDefinition", workspace_id=self.workspace_id)

        response = self.fc.update_item_definition(workspace_id=self.workspace_id,
                                                item_id=blubb3.id, definition=sjd.definition)
        
        self.assertEqual(response.status_code, 200)
        blubb3 = self.fc.get_item(workspace_id=self.workspace_id, item_id=blubb3.id)

        self.assertIn("parts", blubb3.definition)

        self.assertEqual(len(blubb3.definition["parts"]), len(sjd.definition["parts"]))
        sjd_defintion = [part["path"] for part in sjd.definition["parts"] if part["path"] == "SparkJobDefinitionV1.json"]
        blubb3_defintion = [part["path"] for part in blubb3.definition["parts"] if part["path"] == "SparkJobDefinitionV1.json"]
        self.assertEqual(sjd_defintion, blubb3_defintion)
        
        self.assertNotEqual(blubb2.id, sjd.id)
        self.assertIn("parts", blubb2.definition)

        self.assertEqual(len(blubb2.definition["parts"]), len(sjd.definition["parts"]))
        sjd_defintion = [part["path"] for part in sjd.definition["parts"] if part["path"] == "SparkJobDefinitionV1.json"]
        blubb2_defintion = [part["path"] for part in blubb2.definition["parts"] if part["path"] == "SparkJobDefinitionV1.json"]
        self.assertEqual(sjd_defintion, blubb2_defintion)
        self.assertNotEqual(blubb2.id, blubb3.id)
        
        blubb2.delete()
        blubb3.delete()

    def test_item_connections(self):

        fc = self.fc
        connections = fc.list_item_connections(workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3', item_id = '82c01e0c-4cee-4a62-9806-870699ced699')
        self.assertEqual(len(connections), 0)

if __name__ == "__main__":
    unittest.main()


import unittest
from dotenv import load_dotenv
from datetime import datetime
from msfabricpysdkcore import FabricClientCore, FabricClientAdmin


load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)

                  
    def test_domains(self):
        fcc = FabricClientCore()
        fca = FabricClientAdmin()

        ws = fcc.get_workspace_by_name("sdkswedencentral")
        cap = fcc.get_capacity(capacity_id=ws.capacity_id)
        principal = {'id': '1dc64c6e-7a10-4ea9-8488-85d0739a377d',  'type': 'User'}

        # Delete if exists
        for dom in fca.list_domains():
            if "sdktestdomain" in dom.display_name:
                dom.delete()

        # Create domain
        domain_name = "sdktestdomains" + datetime.now().strftime("%Y%m%d%H%M%S")
        domain = fca.create_domain(display_name=domain_name)
        self.assertIsNotNone(domain.id)
        self.assertEqual(domain.display_name, domain_name)

        # Get domain by name
        domain_clone = fca.get_domain_by_name(domain_name)
        self.assertIsNotNone(domain_clone.id)
        self.assertEqual(domain_clone.display_name, domain_name)

        # Get domain by id
        domain_clone = fca.get_domain_by_id(domain.id)
        self.assertIsNotNone(domain_clone.id)
        self.assertEqual(domain_clone.display_name, domain_name)

        # List domains
        domains = fca.list_domains()
        self.assertGreater(len(domains), 0)
        domains_ids = [d.id for d in domains]
        self.assertIn(domain.id, domains_ids)

        # Update domain
        domain_new_name = f"{domain_name}2"
        domain_clone = fca.update_domain(domain.id, display_name=domain_new_name, return_item=True)
        self.assertEqual(domain_clone.display_name, domain_new_name)

        # Assign domain workspaces by Ids
        status_code = fca.assign_domain_workspaces_by_ids(domain.id, [ws.id])
        self.assertEqual(status_code, 200)

        # List domain workspaces
        workspaces = fca.list_domain_workspaces(domain.id, workspace_objects=False)
        self.assertGreater(len(workspaces), 0)
        workspaces_ids = [w["id"] for w in workspaces]
        self.assertIn(ws.id, workspaces_ids)

        # Unassign domain workspaces by ids
        status_code = fca.unassign_domain_workspaces_by_ids(domain.id, [ws.id])
        self.assertEqual(status_code, 200)

        workspaces = fca.list_domain_workspaces(domain.id)
        self.assertEqual(len(workspaces), 0)

        # Assign domain workspaces by capacities
        status_code = fca.assign_domain_workspaces_by_capacities(domain.id, [cap.id])
        self.assertEqual(status_code, 202)

        workspaces = fca.list_domain_workspaces(domain.id, workspace_objects=False)
        self.assertGreater(len(workspaces), 0)
        workspaces_ids = [w["id"] for w in workspaces]
        self.assertIn(ws.id, workspaces_ids)

        # Unassign all domain workspaces
        status_code = fca.unassign_all_domain_workspaces(domain.id)
        self.assertEqual(status_code, 200)

        workspaces = fca.list_domain_workspaces(domain.id)
        self.assertEqual(len(workspaces), 0)

        # Assign domain workspaces by principals
        status_code = fca.assign_domains_workspaces_by_principals(domain.id, [principal], wait_for_completion=False)

        self.assertEqual(status_code, 202)

        workspaces = fca.list_domain_workspaces(domain.id, workspace_objects=False)
        self.assertGreater(len(workspaces), 0)
        workspaces_ids = [w["id"] for w in workspaces]
        self.assertIn(ws.id, workspaces_ids)

        # Role assignments bulk assign
        
        principal_2 = {'id': 'e0505016-ef55-4ca7-b106-e085cc201823', 'type': 'User'}
        principals = [principal, principal_2]

        status_code = fca.role_assignments_bulk_assign(domain.id, "Contributors", principals)

        self.assertEqual(status_code, 200)

        # Role assignments bulk unassign
        status_code = fca.role_assignments_bulk_unassign(domain.id, "Contributors", [principal_2])

        self.assertEqual(status_code, 200)

        # Delete domain
        status_code = fca.delete_domain(domain.id)

        self.assertEqual(status_code, 200)

        domains = fca.list_domains()
        domains_ids = [d.id for d in domains]
        self.assertNotIn(domain.id, domains_ids)


import unittest
from msfabricpysdkcore.coreapi import FabricClientCore
from datetime import datetime
from dotenv import load_dotenv

load_dotenv()


class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()
        self.workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        self.item_id = "9a2edf0f-2318-4179-80d0-1002f3dae7b1"


    def test_jobs_end_to_end(self):
        job = self.fc.run_on_demand_item_job(workspace_id=self.workspace_id,
                                            item_id=self.item_id,
                                            job_type="RunNotebook")
        
        self.assertEqual(job.item_id, self.item_id)
        self.assertEqual(job.workspace_id, self.workspace_id)
        self.assertEqual(job.job_type, "RunNotebook")
        self.assertIn(job.status, ["NotStarted", "InProgress", "Failed"])
        self.assertEqual(job.invoke_type, "Manual")

        job2 = self.fc.get_item_job_instance(workspace_id=self.workspace_id,
                                        item_id=self.item_id,
                                        job_instance_id=job.id)
        
        self.assertEqual(job.id, job2.id)

        status_code = self.fc.cancel_item_job_instance(workspace_id=self.workspace_id,
                                                  item_id=self.item_id,
                                                  job_instance_id=job.id)

        self.assertEqual(status_code, 202)

        job_instances = self.fc.list_item_job_instances(workspace_id=self.workspace_id,
                                                        item_id=self.item_id)
        
        self.assertGreaterEqual(len(job_instances), 1)

    def test_item_schedules(self):

        fc = self.fc


        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        spark_job_definition_name = f"sjd{datetime_str}"

        spark_job_definition_w_content = fc.get_spark_job_definition(workspace_id, spark_job_definition_name="helloworld")
        definition = fc.get_spark_job_definition_definition(workspace_id, spark_job_definition_w_content.id)


        self.assertIsNotNone(definition)
        self.assertIn("definition", definition)
        definition = definition["definition"]

        spark_job_definition = fc.create_spark_job_definition(workspace_id, display_name=spark_job_definition_name, definition=definition)

        self.assertIsNotNone(spark_job_definition)

        configuration = {'type': 'Daily',
                         'startDateTime': '2024-11-21T00:00:00',
                         'endDateTime': '2028-11-08T23:59:00',
                         'localTimeZoneId': 'Romance Standard Time',
                         'times': ['15:39']}

        schedule = spark_job_definition.create_item_schedule(job_type="sparkjob", configuration=configuration, enabled=True)

        schedule_id = schedule["id"]
        schedule_check = spark_job_definition.get_item_schedule(schedule_id=schedule_id, job_type="sparkjob")
        self.assertIsNotNone(schedule_check)
        self.assertEqual(schedule_check["id"], schedule_id)

        schedule_new = spark_job_definition.update_item_schedule(schedule_id=schedule_id, job_type="sparkjob", configuration=configuration, enabled=False)
        self.assertIsNotNone(schedule_new)

        item_id = spark_job_definition.id

        schedule_check = spark_job_definition.get_item_schedule(schedule_id=schedule_id, job_type="sparkjob")
        self.assertEqual(schedule_check["id"], schedule_id)
        self.assertFalse(schedule_check["enabled"])
        list_schedules = fc.list_item_schedules(workspace_id, item_id, job_type="sparkjob")

        self.assertGreater(len(list_schedules), 0)

        spark_job_definition.delete()

if __name__ == "__main__":
    unittest.main()




import unittest
from datetime import datetime
from dotenv import load_dotenv
from time import sleep
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        #load_dotenv()
        self.fc = FabricClientCore()

    def test_lakehouse(self):

        lakehouse2 = "lh2" + datetime.now().strftime("%Y%m%d%H%M%S")
        lakehouse3 = "lh3" + datetime.now().strftime("%Y%m%d%H%M%S")

        workspace_id = '05bc5baa-ef02-4a31-ab20-158a478151d3'
        lhs = self.fc.list_lakehouses(workspace_id=workspace_id, with_properties=True)
        lh = [lh_ for lh_ in lhs if lh_.display_name == "lakelhousewlabels"][0]
        tables = lh.list_tables()
        table_names = [t["name"] for t in tables]
        self.assertIn("dimension_customer", table_names)

        lakehouse = self.fc.get_item(workspace_id=workspace_id, item_name="lakelhousewlabels", item_type="Lakehouse")
        self.assertIsNotNone(lakehouse.properties)
        lakehouse_id = lakehouse.id
        date_str = datetime.now().strftime("%Y%m%d%H%M%S")
        table_name = f"table{date_str}"


        status_code = self.fc.load_table(workspace_id=workspace_id, lakehouse_id=lakehouse_id, table_name=table_name, 
                                         path_type="File", relative_path="Files/to_share/dimension_customer.csv")

        self.assertEqual(status_code, 202)

        # Run on demand table maintenance
        table_name_maintenance = "dimension_customer"

        execution_data = {
            "tableName": table_name_maintenance,
            "optimizeSettings": {
            "vOrder": True,
            "zOrderBy": [
                "CustomerKey",
            ]
            },
            "vacuumSettings": {
            "retentionPeriod": "7:01:00:00"
            }
        }
        
        response = self.fc.run_on_demand_table_maintenance(workspace_id=workspace_id, lakehouse_id=lakehouse_id, 
                                                           execution_data = execution_data,
                                                           job_type = "TableMaintenance", wait_for_completion = False)
        self.assertIn(response.status_code, [200, 202])

        table_list = self.fc.list_tables(workspace_id=workspace_id, lakehouse_id=lakehouse_id)
        table_names = [table["name"] for table in table_list]

        self.assertIn(table_name, table_names)

        fc = self.fc

        lakehouse = fc.create_lakehouse(workspace_id=workspace_id, display_name=lakehouse2)
        self.assertIsNotNone(lakehouse.id)

        lakehouses = fc.list_lakehouses(workspace_id)
        lakehouse_names = [lh.display_name for lh in lakehouses]
        self.assertGreater(len(lakehouse_names), 0)
        self.assertIn(lakehouse2, lakehouse_names)

        lakehouse2 = fc.get_lakehouse(workspace_id=workspace_id, lakehouse_id=lakehouse.id)
        self.assertEqual(lakehouse.id, lakehouse2.id)

        sleep(20)
        lakehouse2 = fc.update_lakehouse(workspace_id=workspace_id, lakehouse_id=lakehouse.id, display_name=lakehouse3, return_item=True)
        self.assertEqual(lakehouse2.display_name, lakehouse3)

        id = lakehouse2.id

        lakehouse2 = fc.get_lakehouse(workspace_id=workspace_id, lakehouse_name=lakehouse3)
        self.assertEqual(lakehouse2.id, id)

        status_code = fc.delete_lakehouse(workspace_id=workspace_id, lakehouse_id=lakehouse.id)
        self.assertEqual(status_code, 200)


import unittest
from dotenv import load_dotenv
from datetime import datetime
from msfabricpysdkcore.coreapi import FabricClientCore

load_dotenv()

class TestFabricClientCore(unittest.TestCase):

    def __init__(self, *args, **kwargs):
        super(TestFabricClientCore, self).__init__(*args, **kwargs)
        self.fc = FabricClientCore()
        
    
    def test_end_to_end_workspace(self):
        fc = self.fc
        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        display_name = "testws" + datetime_str

        datetime_str = datetime.now().strftime("%Y%m%d%H%M%S")
        workspace_name_new = "newws" + datetime_str
        ws_created = fc.create_workspace(display_name=display_name,
                                              description="test workspace", 
                                              exists_ok=False)
        # Add assertions here to verify the result
        self.assertEqual(ws_created.display_name, display_name)
        workspace_id = ws_created.id
        ws = fc.get_workspace_by_id(id = workspace_id)
        self.assertEqual(ws.display_name, display_name)
        self.assertEqual(ws.description, "test workspace")

#   def test_assign_to_capacity(self):
        
        result_status_code = fc.assign_to_capacity(workspace_id=ws.id, 
                                                        capacity_id="9e7e757d-d567-4fb3-bc4f-d230aabf2a00")
        self.assertEqual(result_status_code, 202)
      

#    def test_list_workspaces(self):
        
        result = fc.list_workspaces()
        display_names = [ws.display_name for ws in result]
        self.assertIn(display_name, display_names)

        for ws in result:
            if ws.display_name == display_name:
                self.assertEqual(ws.capacity_id, "9e7e757d-d567-4fb3-bc4f-d230aabf2a00")


  #  def test_get_workspace_by_name(self):

        workspace_name = display_name
        ws = fc.get_workspace_by_name(name = workspace_name)
        self.assertEqual(ws.display_name, display_name)

 #   def test_get_workspace_by_id(self):
        ws = fc.get_workspace_by_id(id = workspace_id)
        self.assertEqual(display_name, ws.display_name)


#    def test_get_workspace(self):
        result = fc.get_workspace_by_id(id = workspace_id)
        self.assertEqual(result.display_name, display_name)
    
 #   def test_add_role_assignment(self):
        result_status = fc.add_workspace_role_assignment(workspace_id = ws.id,
                                                         principal = {"id" : "755f273c-98f8-408c-a886-691794938bd8",
                                                                        "type" : "ServicePrincipal"},
                                                         role = 'Member')
        
        self.assertEqual(result_status, 201)

 #   def test_get_workspace_role_assignments(self):
        result = fc.list_workspace_role_assignments(workspace_id = ws.id)
        self.assertTrue(len(result) == 2)
        for user in result:
            if user["principal"]["displayName"] == "fabrictestuser":
                self.assertEqual(user["role"], "Member")

        # Get get_workspace_role_assignment

        result = fc.get_workspace_role_assignment(workspace_id = ws.id, 
                                                  workspace_role_assignment_id = user["id"])
        
        self.assertEqual(result["role"], "Member")

#    def test_update_workspace_role_assignment(self):

        result_status_code = fc.update_workspace_role_assignment(workspace_id = ws.id, 
                                                                      role = "Contributor", 
                                                                      workspace_role_assignment_id=  user["id"])
        
        self.assertEqual(result_status_code, 200)

        result = fc.list_workspace_role_assignments(workspace_id = ws.id)
        self.assertTrue(len(result) == 2)
        for user in result:
            if user["principal"]["displayName"] == "fabrictestuser":
                self.assertTrue(user["role"] == "Contributor")

#   def test_delete_role_assignment(self):
        result_status_code = fc.delete_workspace_role_assignment(workspace_id = ws.id,
                                                                 workspace_role_assignment_id = user["id"])
        self.assertEqual(result_status_code, 200)

 #   def test_get_workspace_role_assignments(self):
        result = fc.list_workspace_role_assignments(workspace_id = ws.id)
        self.assertTrue(len(result) == 1)
        user = result[0]
#        self.assertTrue(user["principal"]["displayName"] == "fabricapi")
        self.assertTrue(user["role"] == "Admin")

#    def test_update_workspace(self):
        ws_updated = fc.update_workspace(workspace_id=ws.id, 
                                              display_name=workspace_name_new, 
                                              description="new description")
        self.assertEqual(ws_updated.display_name, workspace_name_new)
        self.assertEqual(ws_updated.description, "new description")
        ws = fc.get_workspace_by_id(id = ws.id)
        self.assertEqual(ws.display_name, workspace_name_new)
        self.assertEqual(ws.description, "new description")

#    def test_unassign_from_capacity(self):

        result_status_code = fc.unassign_from_capacity(workspace_id=ws.id)
        self.assertEqual(result_status_code, 202)
        ws = fc.get_workspace_by_id(ws.id)
        self.assertEqual(ws.capacity_id, None)

        # result = fc.provision_identity(workspace_id=ws.id)
        # self.assertIsNotNone(result["applicationId"])
        # fc.deprovision_identity(workspace_id=ws.id)



#    def test_delete_workspace(self):
        result_status = fc.delete_workspace(display_name=workspace_name_new)
        self.assertEqual(result_status, 200)

    def test_list_capacities(self):
        result = self.fc.list_capacities()
        self.assertTrue(len(result) > 0)
        cap_ids = [cap.id for cap in result]
        self.assertIn("9e7e757d-d567-4fb3-bc4f-d230aabf2a00", cap_ids)

    def test_get_capacity(self):
        capacity = self.fc.get_capacity(capacity_id = "9e7e757d-d567-4fb3-bc4f-d230aabf2a00")
        self.assertEqual(capacity.id, "9e7e757d-d567-4fb3-bc4f-d230aabf2a00")

        cap = self.fc.get_capacity(capacity_name= capacity.display_name)

        self.assertEqual(capacity.id, cap.id)
        self.assertIsNotNone(cap.state)
        self.assertIsNotNone(cap.sku)
        self.assertIsNotNone(cap.region)


if __name__ == "__main__":
    unittest.main()